@@ -3,6 +3,8 @@
 use strict;
 use warnings;
 
+our $VERSION = 0;
+
 use Object::Lazy;
 
 my $object = Object::Lazy->new({
@@ -17,38 +19,39 @@ my $object = Object::Lazy->new({
     # tell me when
     logger => sub {
         my $at_stack = shift;
-        print "RealClass $at_stack";
+        () = print "RealClass $at_stack";
     },
 });
 
 {
     my $ok = $object->isa('RealClass');
-    print "$ok = \$object->isa('RealClass');\n";
+    () = print "$ok = \$object->isa('RealClass');\n";
 }
 
 # ask about inheritage
 {
     my $ok = $object->isa('BaseClassOfRealClass');
-    print "$ok = \$object->isa('BaseClassOfRealClass');\n";
+    () = print "$ok = \$object->isa('BaseClassOfRealClass');\n";
 }
 
 # build the real object and call method output
 $object->output();
 
+# $Id$
 
 package RealClass;
 
 use parent qw(-norequire BaseClassOfRealClass);
 
 
-package BaseClassOfRealClass;
+package BaseClassOfRealClass; ## no critic (MultiplePackages)
 
 sub new {
     return bless {}, shift;
 }
 
 sub output {
-    print "# Method output called!\n";
+    () = print "# Method output called!\n";
 
     return;
-}
+}
\ No newline at end of file
