@@ -7,7 +7,7 @@ our $VERSION = '0.01';
 
 use Params::Validate qw(:all);
 
-sub validate_new {
+sub validate_new { ## no critic (ArgUnpacking)
     return validate_with(
         params => \@_,
         spec   => [
@@ -48,6 +48,8 @@ sub init {
     );
 };
 
+# $Id$
+
 1;
 
 __END__
